pub fn export_llm_context(
thread: &ExportThread,
reader_config: &ReaderConfig,
) -> StringExpand description
Export thread optimized for AI consumption. Uses the reader pipeline to strip noise, producing a token-efficient representation.
pub fn export_llm_context(
thread: &ExportThread,
reader_config: &ReaderConfig,
) -> StringExport thread optimized for AI consumption. Uses the reader pipeline to strip noise, producing a token-efficient representation.